==> endeavour_2.7.3.orig.tar.gz: endeavour-2.7.3/endeavour2/find_win_cb.h <==
#ifndef FIND_WIN_CB_H
#define FIND_WIN_CB_H

#include <gtk/gtk.h>
#include "edv_types.h"
#include "find_win.h"


extern void EDVFindWinListItemDestroyCB(gpointer data);

extern gint EDVFindWinDeleteEventCB(
	GtkWidget *widget, GdkEvent *event, gpointer data
);
extern void EDVFindWinDestroyCB(GtkObject *object, gpointer data);

extern gint EDVFindWinCrossingCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);
extern gint EDVFindWinButtonCB(
	GtkWidget *widget, GdkEventButton *button, gpointer data
);

extern void EDVFindWinComboActivateCB(GtkWidget *widget, gpointer data);

extern gint EDVFindWinFindProgressCB(
	const gchar *path, gfloat progress, gpointer data
);

extern void EDVFindWinFindMatchedExcerptCB(
	const gchar *path, const struct stat *lstat_buf,
	const gchar *excerpt, gint line_index,
	gpointer data
);
extern void EDVFindWinFindMatchedCB(
	const gchar *path, const struct stat *lstat_buf,
	gpointer data
);

extern void EDVFindWinClickColumnCB(
	GtkCList *clist, gint column, gpointer data
);
extern void EDVFindWinSelectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);
extern void EDVFindWinUnselectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);

extern void EDVFindWinSearchCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinStopCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinClearCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinCloseCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenWithCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinGotoCB(GtkWidget *widget, gpointer data);

extern void EDVFindWinWriteProtectChangedCB(
	edv_find_win_struct *fw, gboolean state
);
extern void EDVFindWinReconfiguredNotifyCB(edv_find_win_struct *fw);


#endif	/* FIND_WIN_CB_H */

==> endeavour_2.8.4.orig.tar.gz: endeavour-2.8.4/endeavour2/find_win_cb.h <==
#ifndef FIND_WIN_CB_H
#define FIND_WIN_CB_H

#include <gtk/gtk.h>
#include "edv_types.h"
#include "find_win.h"


extern void EDVFindWinListItemDestroyCB(gpointer data);

extern gint EDVFindWinDeleteEventCB(
	GtkWidget *widget, GdkEvent *event, gpointer data
);

extern gint EDVFindWinCrossingCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);
extern gint EDVFindWinButtonCB(
	GtkWidget *widget, GdkEventButton *button, gpointer data
);

extern void EDVFindWinDragDataGetCB(
	GtkWidget *widget, GdkDragContext *dc,
	GtkSelectionData *selection_data, guint info, guint t,
	gpointer data
);
extern void EDVFindWinDragDataDeleteCB(
	GtkWidget *widget, GdkDragContext *dc, gpointer data
);

extern void EDVFindWinComboActivateCB(GtkWidget *widget, gpointer data);

extern void EDVFindWinBrowseLocationCB(GtkWidget *widget, gpointer data);

extern void EDVFindWinFindByChangedCB(
	pulistbox_struct *pulistbox, gint i, gpointer data
);

extern gint EDVFindWinFindProgressCB(
	const gchar *path, gfloat progress, gpointer data
);

extern void EDVFindWinFindMatchExcerptCB(
	const gchar *path, struct stat *lstat_buf,
	const gchar *excerpt, gint line_index,
	gpointer data
);
extern void EDVFindWinFindMatchCB(
	const gchar *path, struct stat *lstat_buf,
	gpointer data
);

extern void EDVFindWinClickColumnCB(
	GtkCList *clist, gint column, gpointer data
);
extern void EDVFindWinSelectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);
extern void EDVFindWinUnselectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);

extern void EDVFindWinSearchCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinStopCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinClearCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinCloseCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenWithCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinGotoCB(GtkWidget *widget, gpointer data);

extern void EDVFindWinWriteProtectChangedCB(
	edv_find_win_struct *fw, gboolean state
);
extern void EDVFindWinReconfiguredNotifyCB(edv_find_win_struct *fw);


#endif	/* FIND_WIN_CB_H */
